itkwasm.pointset - itkwasm python documentation
Description: Module Contents: Classes:,, PointSetType,,, PointSet,,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `itkwasm.pointset`

## Module Contents

### Classes

`PointSetType` |
`PointSet` |

### API

class itkwasm.pointset.PointSetType
  dimension: int

    3

  pointComponentType: Union[itkwasm.int_types.IntTypes, itkwasm.float_types.FloatTypes]

    None

  pointPixelComponentType: Union[itkwasm.int_types.IntTypes, itkwasm.float_types.FloatTypes]

    None

  pointPixelType: itkwasm.pixel_types.PixelTypes

    None

  pointPixelComponents: int

    1

class itkwasm.pointset.PointSet
  pointSetType: Union[itkwasm.pointset.PointSetType, Dict]

    None

  name: str

    ‘PointSet’

  numberOfPoints: int

    0

  points: Optional[numpy.typing.ArrayLike]

    None

  numberOfPointPixels: int

    0

  pointData: Optional[numpy.typing.ArrayLike]

    None

  __post_init__()